ree_map

Macro ree_map 

macro_rules! ree_map {
    ($array:expr, $run_type:ty, $func:expr) => { ... };
}
Recursively applies a function to the values of a RunEndEncoded array, preserving the run structure.

Example

let result = ree_recurse!(array, Int32Type, my_function)?;

This macro is useful for implementing functions that should work on the logical values of a REE array while preserving the run-end encoding structure.