pub fn as_fixed_size_list_array(arr: &dyn Array) -> &FixedSizeListArrayExpand description
Force downcast of an Array, such as an ArrayRef to
FixedSizeListArray.
Panics
Panics if arr is not a FixedSizeListArray
pub fn as_fixed_size_list_array(arr: &dyn Array) -> &FixedSizeListArrayForce downcast of an Array, such as an ArrayRef to
FixedSizeListArray.
Panics if arr is not a FixedSizeListArray