pub fn as_large_list_array(arr: &dyn Array) -> &LargeListArrayExpand description
Force downcast of an Array, such as an ArrayRef to
LargeListArray.
Panics
Panics if arr is not a LargeListArray
pub fn as_large_list_array(arr: &dyn Array) -> &LargeListArrayForce downcast of an Array, such as an ArrayRef to
LargeListArray.
Panics if arr is not a LargeListArray