pub fn as_struct_array(arr: &dyn Array) -> &StructArrayExpand description
Force downcast of an Array, such as an ArrayRef to
StructArray
Panics
Panics if arr is not a
StructArray
pub fn as_struct_array(arr: &dyn Array) -> &StructArrayForce downcast of an Array, such as an ArrayRef to
StructArray
Panics if arr is not a
StructArray